Module blaxel.core.client.models.job_execution_stats
====================================================

Classes
-------

`JobExecutionStats(cancelled: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, failure: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, retried: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, running: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, success: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, total: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>)`
:   Job execution statistics
    
    Attributes:
        cancelled (Union[Unset, int]): Number of cancelled tasks
        failure (Union[Unset, int]): Number of failed tasks
        retried (Union[Unset, int]): Number of retried tasks
        running (Union[Unset, int]): Number of running tasks
        success (Union[Unset, int]): Number of successful tasks
        total (Union[Unset, int]): Total number of tasks
    
    Method generated by attrs for class JobExecutionStats.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `cancelled: blaxel.core.client.types.Unset | int`
    :

    `failure: blaxel.core.client.types.Unset | int`
    :

    `retried: blaxel.core.client.types.Unset | int`
    :

    `running: blaxel.core.client.types.Unset | int`
    :

    `success: blaxel.core.client.types.Unset | int`
    :

    `total: blaxel.core.client.types.Unset | int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :